pub struct RecursiveParser<I: ?Sized, O, F>{ /* private fields */ }Trait Implementations
Sourceimpl<I: ?Sized, O, F> Clone for RecursiveParser<I, O, F>
impl<I: ?Sized, O, F> Clone for RecursiveParser<I, O, F>
Sourceimpl<I: ?Sized, O, F> Parser for RecursiveParser<I, O, F>
impl<I: ?Sized, O, F> Parser for RecursiveParser<I, O, F>
Sourceimpl<I: ?Sized, O, F> ParserCombinator for RecursiveParser<I, O, F>
impl<I: ?Sized, O, F> ParserCombinator for RecursiveParser<I, O, F>
Sourcefn then<P: Parser<I = Self::I>>(&self, p: P) -> ChainedParser<Self, P>
fn then<P: Parser<I = Self::I>>(&self, p: P) -> ChainedParser<Self, P>
Chain this parser with another parser, creating new parser that returns a
tuple of their results
Sourcefn then_r<P: ParserCombinator<I = Self::I>>(
&self,
p: P,
) -> MapParser<Self::I, ChainedParser<Self, P>, P::O>
fn then_r<P: ParserCombinator<I = Self::I>>( &self, p: P, ) -> MapParser<Self::I, ChainedParser<Self, P>, P::O>
Chain this parser with another parser, but toss the value from this parser
Sourcefn then_l<P: ParserCombinator<I = Self::I>>(
&self,
p: P,
) -> MapParser<Self::I, ChainedParser<Self, P>, Self::O>
fn then_l<P: ParserCombinator<I = Self::I>>( &self, p: P, ) -> MapParser<Self::I, ChainedParser<Self, P>, Self::O>
Chain this parser with another parser, but toss the value from the other parser
Sourcefn repeat(&self) -> RepeatParser<Self>
fn repeat(&self) -> RepeatParser<Self>
Create a new parser that will repeat this parser until it returns an error